@@ -43,4 +43,10 @@ class Score:
     directionals: list[Note]
     slides: list[list[Note]]
     bpms: list[tuple[int, float]]
-    bar_lengths: list[tuple[int, float]]
\ No newline at end of file
+    bar_lengths: list[tuple[int, float]]
+    
+@dataclass
+class BarLength:
+    start_tick: int
+    measure: int
+    value: float
\ No newline at end of file
